dhg.visualization
====================

Structure Visualization
---------------------------

Graph
~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.draw_graph


Directed Graph
~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.draw_digraph

Bipartite Graph
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.draw_bigraph

Hypergraph
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.draw_hypergraph

Feature Visualization
---------------------------

Feature Visualization in Euclidean Space
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.draw_in_euclidean_space


Feature Visualization in Poincare Ball
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.project_to_poincare_ball

.. autofunction:: dhg.visualization.draw_in_poincare_ball


Make Animations
~~~~~~~~~~~~~~~~~~

.. autofunction:: dhg.visualization.animation_of_3d_euclidean_space

.. autofunction:: dhg.visualization.animation_of_3d_poincare_ball

